//+------------------------------------------------------------------+
//|                                                    my_oop_ea.mq5 |
//|                        Copyright 2010, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2010, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"
// Include  our class
#include <Jatin3PairEA.mqh>
#include<Trade\Trade.mqh>
#include <Trade\PositionInfo.mqh>                                  //include the library for obtaining information on 
//--- input parameters
input int      StopLoss=30;      // Stop Loss
input int      TakeProfit=100;   // Take Profit
input int      ADX_Period=14;    // ADX Period
input int      MA_Period=10;     // Moving Average Period
input int      EA_Magic=12345;   // EA Magic Number
input double   Adx_Min=22.0;     // Minimum ADX Value
input double   Lot=0.1;          // Lots to Trade
input int      Margin_Chk=1;     // Check Margin before placing trade(0=No, 1=Yes)
input double   Trd_percent=15.0; // Percentage of Free Margin To use for Trading
input double   AccountTP = 0.6;
input double   AccountSL = 20 ;
input ENUM_TIMEFRAMES   period = PERIOD_CURRENT; 
input string   EA_Symbols = "GBPUSD;USDCHF;GBPCHF";
input string   EA_Symbols_Seperator = ";";
//--- other parameters
int STP,TKP;   // To be used for Stop Loss & Take Profit values
//--- create an object of our class
MyExpert Cexpert[3];

string EA_Symbols_Array[];
int Symbol_Signal [];
ENUM_ORDER_TYPE Symbol_Send_OrderType [];
int symbol_size  = 0 ;
//BUY BUY SELL
ENUM_ORDER_TYPE BBS[] ={ORDER_TYPE_BUY,ORDER_TYPE_BUY,ORDER_TYPE_SELL};
//SELL SELL BUY
ENUM_ORDER_TYPE SSB[] ={ORDER_TYPE_SELL,ORDER_TYPE_SELL,ORDER_TYPE_BUY};

int BBSorSSB = -1 ;  // 1 for bbs , 2 for ssb

CPositionInfo     m_Position;                              //structure for obtaining information of positions
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
	  
	  symbol_size = StringSplit(EA_Symbols,StringGetCharacter(EA_Symbols_Seperator,0),EA_Symbols_Array);
	  if( symbol_size != 3 ){
		Alert("Provide Proper Symbols");
		return 0;
	  }
//--- Set event generation frequency
	  EventSetTimer(1); // 1 second

//--- let us handle brokers that offers 5 digit prices instead of 4
   STP = StopLoss;
   TKP = TakeProfit;
   if(_Digits==5)
     {
      STP = STP*10;
      TKP = TKP*10;
     }
	  
//--- run Initialize function	  
   for (int i = 0 ; i <	 symbol_size  ; i++){
   	   Cexpert[i].doInit(ADX_Period,MA_Period); //--- set all other necessary variables for our class object
		   Cexpert[i].setPeriod(period);    // sets the chart period/timeframe
		   Cexpert[i].setSymbol(EA_Symbols_Array[i]);    // sets the chart symbol/currency-pair
		   Cexpert[i].setMagic(EA_Magic);    // sets the Magic Number
		   Cexpert[i].setadxmin(Adx_Min);    // sets the ADX miniumm value
		   Cexpert[i].setLOTS(Lot);          // set the Lots value
		   Cexpert[i].setchkMAG(Margin_Chk); // set the margin check variable
		   Cexpert[i].setTRpct(Trd_percent); // set the percentage of Free Margin for trade
		   Cexpert[i].setSTP(STP);    // sets the setSTP Number
		   Cexpert[i].setTKP(TKP);    // sets the setTKP Number
   } 

   return(0);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
  //--- Termination of event generation
   EventKillTimer();
//--- Run UnIntilialize function
	for (int i = 0 ; i <	 symbol_size  ; i++){
		Cexpert[i].doUninit();
	 }
   }

int DayOfWeek()
{
   MqlDateTime tm;
   TimeCurrent(tm);
   return(tm.day_of_week);
}

double calculateProfit(){
 double profit = 0 ;
 for(int i = 0 ; i< symbol_size ; i++){
	 /*
	if(m_Position.Select(EA_Symbols_Array[i]) && m_Position.Magic() == EA_Magic){
		profit = profit + m_position.Profit();
	 } 
    */
	 if(m_Position.SelectByMagic(EA_Symbols_Array[i],EA_Magic)){
		 profit = profit + m_Position.Profit();
	 }
  }
 return profit;
}

void closeAllOrder(){
	
		/*
		if(m_Position.Select(EA_Symbols_Array[i]) && m_Position.Magic() == EA_Magic){
			while(!m_Trade.PositionClose(EA_Symbols_Array[i],1000));
		}
		*/
		/*
	if(m_Position.SelectByMagic(EA_Symbols_Array[i],EA_Magic)){
		 while(!m_Position.PositionClose(EA_Symbols_Array[i],1000));
		 
	 }*/
	  int PosTotal=OrdersTotal();
	 for(int i=PosTotal-1; i>=0; i--){
	 
	   for(int j = 0 ; j< symbol_size ; j++){
	    
	     if(PositionGetSymbol(i)==EA_Symbols_Array[j]){
	        if(EA_Magic==PositionGetInteger(POSITION_MAGIC))
            {
               if(PositionGetInteger(POSITION_TYPE)>1){
                  ulong tkt=OrderGetTicket(i);
                  CTrade *trade=new CTrade;
                   trade.OrderDelete(tkt);
               
              }
            }
	      }         
	 
      }
	 
	     
	  }
      
	 		
	
}

int orderOpened(){
 int ordOpened = 0 ;
 for(int i = 0 ; i< symbol_size ; i++){
	if(m_Position.Select(EA_Symbols_Array[i]) && m_Position.Magic() == EA_Magic){
		ordOpened++;
	 }   
 }
 return ordOpened;
}

void prepareSignal(){
	 for (int i = 0 ; i <	 symbol_size  ; i++){
   	    Symbol_Signal[i] = Cexpert[i].getBuySellSignal(); 
	}
}

//BUY BUY SELL
//SELL SELL BUY
// 0 - nothing , 1-Buy , 2-Sell
void prepareOrderSendType(){
	int bbs = 0 , ssb = 0 ;
	for (int i = 0 ; i <	 symbol_size  ; i++){
   	    if(Symbol_Signal[i] == BBS[i]){
			bbs++;
		}
		if(Symbol_Signal[i] == SSB[i]){
			ssb++;
		}
		if(bbs < ssb){
			BBSorSSB = 2;
		}else if(bbs > ssb){
			BBSorSSB = 1;
		}else{
			BBSorSSB = -1;
		}
	}
}
  
 void placeBBS(){
	 for (int i = 0 ; i <	 symbol_size  ; i++){
   	    while(!Cexpert[i].openBuySell(BBS[i])){};
	}
 }

void placeSSB(){
	 for (int i = 0 ; i <	 symbol_size  ; i++){
   	    while(!Cexpert[i].openBuySell(SSB[i])){};
	}
 } 
//-===================== The OnTimer function ======================================================  
void OnTimer()
  {
	int dayOfWeek = DayOfWeek();
	if( dayOfWeek == 0 || dayOfWeek == 6 ){
		Sleep(900000); // 15 min
		return;
	}
	 double acProfit = calculateProfit();
	if( acProfit > AccountTP  || acProfit < AccountSL){
		closeAllOrder();
	}
		
	 if(orderOpened() > 0)  // FUTURE DEVELOPMENT : ALL ORDERS ARE OPEN OR NOT
	 {
		 return;
	 }
	

//--- do we have enough bars to work with
/*
   int Mybars=Bars(_Symbol,_Period);
   if(Mybars<60) // if total bars is less than 60 bars
     {
      Print("We have less than 60 bars, EA will now exit!!");
      return;
     }
*/

//--- define some MQL5 Structures we will use for our trade
  // MqlTick latest_price;      // To be used for getting recent/latest price quotes
 //  MqlRates mrate[];          // To be used to store the prices, volumes and spread of each bar
/*
     Let's make sure our arrays values for the Rates
     is store serially similar to the timeseries array
*/
//--- the rates arrays
//   ArraySetAsSeries(mrate,true);

//--- Get the last price quote using the MQL5 MqlTick Structure
 /*  if(!SymbolInfoTick(_Symbol,latest_price))
     {
      Print("Error getting the latest price quote - error:",GetLastError(),"!!");
      return;
     }
*/
//--- get the details of the latest 3 bars
/*
   if(CopyRates(_Symbol,period,0,3,mrate)<0)
     {
      Print("Error copying rates/history data - error:",GetLastError(),"!!");
      return;
     }
*/
/*	 
//--- EA should only check for new trade if we have a new bar
//--- lets declare a static datetime variable
   static datetime Prev_time;
//--- lets declare a datetmie variable to hold the start time for the current bar (Bar 0)
   datetime Bar_time[1];

//--- copy the start time of the new bar to the variable
   Bar_time[0]=mrate[0].time;
//--- we don't have a new bar when both times are the same
   if(Prev_time==Bar_time[0])
     {
      return;
     }
//--- copy time to static value, save
   Prev_time=Bar_time[0];
*/
//--- we have no errors, so continue
//--- do we have positions opened already?
/*
   bool Buy_opened=false,Sell_opened=false; // variables to hold the result of the opened position

   if(PositionSelect(_Symbol)==true) // we have an opened position
     {
      if(PositionGetInteger(POSITION_TYPE)==POSITION_TYPE_BUY)
        {
         Buy_opened=true;  //It is a Buy
        }
      else if(PositionGetInteger(POSITION_TYPE)==POSITION_TYPE_SELL)
        {
         Sell_opened=true; // It is a Sell
        }
     }
	 */
//--- copy the bar close price for the previous bar prior to the current bar, that is Bar 1
 //  Cexpert.setCloseprice(mrate[1].close);  // bar 1 close price
//--- check for Buy position
 
    prepareSignal();
	prepareOrderSendType();
	if( BBSorSSB == -1 ) return ;
	
	if( BBSorSSB == 1 ){
		placeBBS();
	}else if( BBSorSSB == 2){
		placeSSB();
	}
	
	/*
   if(Cexpert.checkBuy()==true)
     {
      //--- do we already have an opened buy position
      if(Buy_opened)
        {
         Print("We already have a Buy Position!!!");
         return;    // Don't open a new Buy Position
        }
   // place order
      while(!Cexpert.openBuySell(ORDER_TYPE_BUY)){};
     }
//--- check for any Sell position
   if(Cexpert.checkSell()==true)
     {
      //--- do we already have an opened Sell position
      if(Sell_opened)
        {
         Print("We already have a Sell position!!!");
         return;    // Don't open a new Sell Position
        }
      // place order
      while(!Cexpert.openBuySell(ORDER_TYPE_SELL)){};
     }
		return; 
*/		
  }
  
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
  }
//+------------------------------------------------------------------+
